@@ -31,7 +31,7 @@ def get_oidc_configuration(app):
     discovery_doc_url = issuer_url.strip('/') + '/.well-known/openid-configuration'
 
     try:
-        r = requests.get(discovery_doc_url)
+        r = requests.get(discovery_doc_url, timeout=2)
         config = r.json()
     except Exception as e:
         raise ApiError('Could not get OpenID configuration from well known URL: {}'.format(str(e)), 503)
@@ -46,7 +46,7 @@ def get_oidc_configuration(app):
     if app.config['OIDC_VERIFY_TOKEN']:
         try:
             jwks_uri = config['jwks_uri']
-            r = requests.get(jwks_uri)
+            r = requests.get(jwks_uri, timeout=2)
             keys = {k['kid']: RSAAlgorithm.from_jwk(json.dumps(k)) for k in r.json()['keys']}
         except Exception as e:
             raise ApiError('Could not get OpenID JWT Key Set from JWKS URL: {}'.format(str(e)), 503)
@@ -128,17 +128,24 @@ def openid():
     if not login:
         raise ApiError("Must support one of the following OpenID claims: 'preferred_username', 'nickname' or 'email'", 400)
 
-    user = User.find_by_id(id=subject)
+    if current_app.config['OIDC_LINK_USER_EMAIL'] and email and email_verified:
+        user = User.find_by_email(email=email)
+    else:
+        user = User.find_by_id(id=subject)
+
     if not user:
         user = User(id=subject, name=name, login=login, password='', email=email,
-                    roles=[], text='', email_verified=email_verified)
+                    roles=current_app.config['USER_ROLES'], text='', email_verified=email_verified)
         user.create()
     else:
-        user.update(login=login, email=email)
+        user.update(login=login, email=email, email_verified=email_verified)
 
     roles = custom_claims[role_claim] + user.roles
     groups = custom_claims[group_claim]
 
+    if user.id != subject:
+        custom_claims['oid'] = user.id  # if subject differs store the original subject as "oid" claim
+
     if user.status != 'active':
         raise ApiError('User {} is not active'.format(login), 403)
 
