@@ -490,8 +490,13 @@ class Backend(Database):
             return_document=ReturnDocument.AFTER
         )
 
-    def get_alerts(self, query=None, page=None, page_size=None):
+    def get_alerts(self, query=None, raw_data=False, history=False, page=None, page_size=None):
         query = query or Query()
+        fields = dict()
+        if not raw_data:
+            fields['rawData'] = 0
+        if not history:
+            fields['history'] = 0
         pipeline = [
             {'$lookup': {
                 'from': 'codes',
@@ -510,6 +515,7 @@ class Backend(Database):
             {'$replaceRoot': {'newRoot': {'$mergeObjects': [{'$arrayElemAt': ['$fromStates', 0]}, '$$ROOT']}}},
             {'$project': {'fromStates': 0}},
             {'$match': query.where},
+            {'$project': fields},
             {'$sort': {k: v for k, v in query.sort}},
             {'$skip': (page - 1) * page_size},
             {'$limit': page_size}
