@@ -1,6 +1,5 @@
-
 from flask import Blueprint
 
 mgmt = Blueprint('mgmt', __name__)
 
-from . import views
+from . import views  # noqa isort:skip
