@@ -50,6 +50,7 @@ def config():
             'mediumDate': current_app.config['DATE_FORMAT_MEDIUM_DATE'],
             'longDate': current_app.config['DATE_FORMAT_LONG_DATE']
         },
+        'font': current_app.config['DEFAULT_FONT'],
         'audio': {
             'new': current_app.config['DEFAULT_AUDIO_FILE']
         },
@@ -62,5 +63,6 @@ def config():
         },
         'actions': current_app.config['ACTIONS'],
         'tracking_id': current_app.config['GOOGLE_TRACKING_ID'],
-        'refresh_interval': current_app.config['AUTO_REFRESH_INTERVAL']
+        'refresh_interval': current_app.config['AUTO_REFRESH_INTERVAL'],
+        'environments': current_app.config['ALLOWED_ENVIRONMENTS']
     })
